@@ -362,3 +362,32 @@ NvMTriTrophicStatistics <- function(community)
     return (res)
 }
 
+.PolygonArea <- function(x, y)
+{
+    # htncp://en.wikipedia.org/wiki/Polygon#Area_and_centroid
+    stopifnot(length(x)==length(y))
+    upper <- 2:length(x)
+    lower <- upper-1
+    return (abs(0.5 * sum(x[lower]*y[upper] - x[upper]*y[lower])))
+}
+
+.ConvexHull <- function(community, x, y)
+{
+    p <- cbind(x, y)
+    rownames(p) <- NULL
+    p <- p[!is.na(p[,1]) & !is.na(p[,2]),]
+    hull <- chull(p)
+
+    # Close polygon for calculation of area
+    return (list(nodes=unname(NP(community, 'node')[hull]),
+                 points=p[hull,], 
+                 area=.PolygonArea(p[c(hull,hull[1]),1], p[c(hull,hull[1]),2])))
+}
+
+NvMConvexHull <- function(community)
+{
+    if(!is.Community(community)) stop('Not a Community')
+    cheddar:::.RequireM(community)
+    cheddar:::.RequireN(community)
+    return (.ConvexHull(community, Log10M(community), Log10N(community)))
+}
